/*
 * Copyright 2013 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.gradle.tooling.internal.provider

import org.gradle.internal.logging.services.LoggingServiceRegistry
import org.gradle.internal.service.ServiceRegistryBuilder
import org.gradle.testfixtures.internal.NativeServicesTestFixture
import org.gradle.tooling.internal.adapter.ProtocolToModelAdapter
import spock.lang.Specification

class ConnectionScopeServicesTest extends Specification {
    def logging = LoggingServiceRegistry.newEmbeddableLogging()
    def services = ServiceRegistryBuilder.builder()
        .parent(logging)
        .parent(NativeServicesTestFixture.instance)
        .provider(new ConnectionScopeServices())
        .build()

    def "provides a ProviderConnection implementation"() {
        expect:
        services.get(ProviderConnection) instanceof ProviderConnection
    }

    def "provides a ProtocolToModelAdapter implementation"() {
        expect:
        services.get(ProtocolToModelAdapter) instanceof ProtocolToModelAdapter
    }
}
